@@ -34,6 +34,7 @@ use AsyncAws\Sns\Exception\TagLimitExceededException;
 use AsyncAws\Sns\Exception\TagPolicyException;
 use AsyncAws\Sns\Exception\TooManyEntriesInBatchRequestException;
 use AsyncAws\Sns\Exception\TopicLimitExceededException;
+use AsyncAws\Sns\Exception\ValidationException;
 use AsyncAws\Sns\Input\CreatePlatformEndpointInput;
 use AsyncAws\Sns\Input\CreateTopicInput;
 use AsyncAws\Sns\Input\DeleteEndpointInput;
@@ -108,6 +109,7 @@ class SnsClient extends AbstractApi
      *   Name: string,
      *   Attributes?: array<string, string>,
      *   Tags?: Tag[],
+     *   DataProtectionPolicy?: string,
      *   @region?: string,
      * }|CreateTopicInput $input
      *
@@ -271,6 +273,7 @@ class SnsClient extends AbstractApi
      * @throws KMSThrottlingException
      * @throws KMSAccessDeniedException
      * @throws InvalidSecurityException
+     * @throws ValidationException
      */
     public function publish($input): PublishResponse
     {
@@ -290,6 +293,7 @@ class SnsClient extends AbstractApi
             'KMSThrottling' => KMSThrottlingException::class,
             'KMSAccessDenied' => KMSAccessDeniedException::class,
             'InvalidSecurity' => InvalidSecurityException::class,
+            'ValidationException' => ValidationException::class,
         ]]));
 
         return new PublishResponse($response);
@@ -328,6 +332,7 @@ class SnsClient extends AbstractApi
      * @throws KMSThrottlingException
      * @throws KMSAccessDeniedException
      * @throws InvalidSecurityException
+     * @throws ValidationException
      */
     public function publishBatch($input): PublishBatchResponse
     {
@@ -352,6 +357,7 @@ class SnsClient extends AbstractApi
             'KMSThrottling' => KMSThrottlingException::class,
             'KMSAccessDenied' => KMSAccessDeniedException::class,
             'InvalidSecurity' => InvalidSecurityException::class,
+            'ValidationException' => ValidationException::class,
         ]]));
 
         return new PublishBatchResponse($response);
@@ -453,20 +459,6 @@ class SnsClient extends AbstractApi
                     'signService' => 'sns',
                     'signVersions' => ['v4'],
                 ];
-            case 'us-iso-west-1':
-                return [
-                    'endpoint' => "https://sns.$region.c2s.ic.gov",
-                    'signRegion' => $region,
-                    'signService' => 'sns',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-isob-east-1':
-                return [
-                    'endpoint' => "https://sns.$region.sc2s.sgov.gov",
-                    'signRegion' => $region,
-                    'signService' => 'sns',
-                    'signVersions' => ['v4'],
-                ];
             case 'fips-us-east-1':
                 return [
                     'endpoint' => 'https://sns-fips.us-east-1.amazonaws.com',
@@ -495,28 +487,14 @@ class SnsClient extends AbstractApi
                     'signService' => 'sns',
                     'signVersions' => ['v4'],
                 ];
-            case 'us-east-1':
-                return [
-                    'endpoint' => 'https://sns.us-east-1.amazonaws.com',
-                    'signRegion' => 'us-east-1',
-                    'signService' => 'sns',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-east-2':
-                return [
-                    'endpoint' => 'https://sns.us-east-2.amazonaws.com',
-                    'signRegion' => 'us-east-2',
-                    'signService' => 'sns',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-gov-east-1':
+            case 'fips-us-gov-east-1':
                 return [
                     'endpoint' => 'https://sns.us-gov-east-1.amazonaws.com',
                     'signRegion' => 'us-gov-east-1',
                     'signService' => 'sns',
                     'signVersions' => ['v4'],
                 ];
-            case 'us-gov-west-1':
+            case 'fips-us-gov-west-1':
                 return [
                     'endpoint' => 'https://sns.us-gov-west-1.amazonaws.com',
                     'signRegion' => 'us-gov-west-1',
@@ -524,23 +502,17 @@ class SnsClient extends AbstractApi
                     'signVersions' => ['v4'],
                 ];
             case 'us-iso-east-1':
+            case 'us-iso-west-1':
                 return [
-                    'endpoint' => 'https://sns.us-iso-east-1.c2s.ic.gov',
-                    'signRegion' => 'us-iso-east-1',
+                    'endpoint' => "https://sns.$region.c2s.ic.gov",
+                    'signRegion' => $region,
                     'signService' => 'sns',
                     'signVersions' => ['v4'],
                 ];
-            case 'us-west-1':
+            case 'us-isob-east-1':
                 return [
-                    'endpoint' => 'https://sns.us-west-1.amazonaws.com',
-                    'signRegion' => 'us-west-1',
-                    'signService' => 'sns',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-west-2':
-                return [
-                    'endpoint' => 'https://sns.us-west-2.amazonaws.com',
-                    'signRegion' => 'us-west-2',
+                    'endpoint' => 'https://sns.us-isob-east-1.sc2s.sgov.gov',
+                    'signRegion' => 'us-isob-east-1',
                     'signService' => 'sns',
                     'signVersions' => ['v4'],
                 ];
